@@ -148,7 +148,7 @@ class Dispatcher(BaseDispatcher[Callable]):
         :returns: Result of execution the user-defined function.
         """
         try:
-            user_function: Callable = self[function_name]
+            user_function: Final[Callable] = self[function_name]
         except KeyError as exc:
             raise Error(code=ErrorEnum.METHOD_NOT_FOUND, message=f"Function {function_name!r} isn't found") from exc
 
