@@ -124,7 +124,7 @@ class Request(BaseRequest):
         if not isinstance(method, str) or method.startswith("\x72\x70\x63\x2E"):
             raise Error(
                 code=ErrorEnum.INVALID_REQUEST,
-                message=f"Request method must be a string and doesn't have a \"rpc.\" prefix")
+                message="Request method must be a string and doesn't have a \"rpc.\" prefix")
 
         return method
 
